@@ -12,19 +12,23 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.25_01';
+	$VERSION = '1.25_02';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
 use constant UNBOUND_VERSION => eval {
-        my $version = Net::DNS::Resolver::libunbound->VERSION();
-        my ($v1,$v2,$v3) = split /\D/, $version;
-        ( $v1 * 100 + $v2 ) * 100 + $v3;
+	my $version = Net::DNS::Resolver::libunbound->VERSION();
+	my ( $v1, $v2, $v3 ) = split /\D/, $version;
+	( $v1 * 100 + $v2 ) * 100 + $v3;
 };
 
-
 use constant UB_CONTEXT => 'Net::DNS::Resolver::Unbound::Context';
 
+use constant IP_PREF	 => UNBOUND_VERSION > 11100;
+use constant SET_TLS	 => UB_CONTEXT->can('set_tls');
+use constant SET_STUB	 => UB_CONTEXT->can('set_stub');
+use constant ADD_TA_AUTR => UB_CONTEXT->can('add_ta_autr');
+
 
 =head1 NAME
 
@@ -263,8 +267,6 @@ Use DNS over TLS for queries to nameservers specified using set_fwd().
 
 =cut
 
-use constant SET_TLS => UB_CONTEXT->can('set_tls');
-
 sub set_tls {
 	my ( $self, $tls ) = @_;
 	return SET_TLS ? $self->_config( 'set_tls', $tls ) : undef;
@@ -281,8 +283,6 @@ and the 'DHCP DNS' IP address, use set_fwd().
 
 =cut
 
-use constant SET_STUB => UB_CONTEXT->can('set_stub');
-
 sub set_stub {
 	my ( $self, $zone, $address, $prime ) = @_;
 	return SET_STUB ? $self->_config( 'set_stub', $zone, $address, $prime ) : undef;
@@ -363,8 +363,6 @@ trust anchor is changed.
 
 =cut
 
-use constant ADD_TA_AUTR => UB_CONTEXT->can('add_ta_autr');
-
 sub add_ta_autr {
 	my ( $self, $filename ) = @_;
 	return ADD_TA_AUTR ? $self->_config( 'add_ta_autr', $filename ) : undef;
@@ -557,7 +555,7 @@ my %IP_conf = (
 	prefer_v4 => ['prefer-ip4:' => 'yes'],
 	prefer_v6 => ['prefer-ip6:' => 'yes'] );
 my @IPpref = map {@$_} values %IP_conf;
-delete @IP_conf{qw(prefer_v4 prefer_v6)} if UNBOUND_VERSION < 11100;
+delete @IP_conf{qw(prefer_v4 prefer_v6)} unless IP_PREF;
 my @IPconf = sort keys %IP_conf;
 
 sub _finalise_config {
